@@ -283,4 +283,4 @@ class JSONField(forms.CharField):
     def prepare_value(self, value):
         if isinstance(value, InvalidJSONInput):
             return value
-        return json.dumps(value)
+        return json.dumps(value, ensure_ascii=False)
