@@ -384,6 +384,10 @@ class FoundRowsTests(TestCase):
             assert authors.found_rows == 10
 
     def test_it_working_prefetching(self):
+        author1, author2 = Author.objects.all()[:2]
+        author2.tutor = author1
+        author2.save()
+
         with self.assertNumQueries(3):
             authors = Author.objects.sql_calc_found_rows().prefetch_related("tutor")[:5]
             list(authors)
@@ -606,9 +610,10 @@ class SmartIteratorTests(TestCase):
         AuthorExtra.objects.create(author=author, legs=2)
         AuthorExtra.objects.create(author=author2, legs=1)
 
-        seen_author_ids = []
-        for extra in AuthorExtra.objects.iter_smart():
-            seen_author_ids.append(extra.author_id)
+        seen_author_ids = [
+            extra.author_id for extra in AuthorExtra.objects.iter_smart()
+        ]
+
         assert seen_author_ids == [author.id, author2.id]
 
     def test_iter_smart_fk_string_primary_key_fails(self):
